@@ -1,6 +1,6 @@
 """Module containing objects for visualization of the embeddings."""
-from .graph_visualizations import GraphVisualizations
+from .graph_visualization import GraphVisualization
 
 __all__ = [
-    "GraphVisualizations"
+    "GraphVisualization"
 ]
